# wpilib.kinematics

This is a pure-Python port of the WPILib 2020 kinematics classes for RobotPy 2019.

Note: This is provided on a best-effort basis. Things may move or become unavailable in RobotPy WPILib 2020.

## Installation
`pip install wpilib.kinematics`
